%% demo Sym-LSM from real images
%
% The demo routine demo_LSM_image_pairs.m allows to apply Sym-LSM 
% to real data. Approximate values can be provided interactively, 
% or - later - read from file. This refers to the centre of the 
% two windows, their individual scale  and their individual main 
% direction, following the notion of scale and direction of 
% Lowe's keypoints.  
%
% main control parameters
% =======================
% img_name_1    = name of first image
% img_name_2    = name of first image
% read_X        = 0/1 interactively define points,/ read points
% s,t           = parameters for noise sigma_n^2=s+t*f
% sigma         = smoothing kernel size, if = 0: no smoothing
% N_iter        = maximum number of iterations
% 
% 
% wf 11/2018



clearvars
close all

addpath(genpath('src/')) 

par.ss = plot_init();

disp(' --------------------------------------------------------------------- ')
disp(' ---- symmetric LSM with 6 geometric and 2 radiometric parameters ---- ')
disp(' ----              interactive correspondences                    ---- ')
disp(' --------------------------------------------------------------------- ')

% suppress warning, that image is too large for display
warning('off','images:initSize:adjustingMag')

%% Choose your own parameters (default = 2)
% --- type data --------------------------------------------------------
    % par.type_data = 1;  % Desert
     par.type_data = 2;  % Stockholm
    % par.type_data = 3;  % % Peking
    % par.type_data = 4;   % % Prag

%% Parameters ==========================================================
par = image_pair_set_parameters(par);

%% Images and coordinates
[Nig,Nih,Image_l,Image_r,X,par] = image_pair_provide_images_and_coordinates(par);

%% approximate values and weights
[g,h,x_approx,par] = image_pair_approximate_values_weights(Nig,Nih,Image_l,Image_r,X,par);
 

% ---  minimum size of overlap  ------------------------------
Nf_MIN = par.Nf_MIN;
disp(['Minimum size of overlap                                  : ', num2str(Nf_MIN),'x', num2str(Nf_MIN)])

%% start  ===========================================================

% set parameters
vg              = par.vg;           % 256x1 noise variance function g
vh              = par.vh;           % 256x1 noise variance function h
A_a             = par.A_a;          % 3x3 approx. geometric transformation
R_a             = par.R_a;          %1x2  approx. geometric transformation
sigma_smooth    = par.sigma_smooth; % smoothing parameter for f
max_iter        = par.max_iter;      % maximal number of iterations
plot_type       = par.plot_type     % in [0,1,2] level of output

% activate for more details
% plot_type = 2;

% for generating input data for demo_LSM_small.m
% save('example_data/Sym_LSM_small_demo','g','h','vg','vh','A_a','R_a')


% for generating input data for demo_LSM_medium.m
% save('example_data/Sym_LSM_medium_demo','Image_l','Image_r','X')

tic;
% --- estimate transformation (LSM_62_sym_main) ----------------- ---

[est_x,est_sigma_0,NN,Nf,Red,N_iter] = LSM_62_sym_warp_main...
    (g,h,vg,vh,A_a,R_a,sigma_smooth,max_iter,Nf_MIN,plot_type);

% --- estimate transformation (LSM_62_sym_main) --------------------
LSM_time=toc



if Red > 0 
    
    A_est   = [reshape(est_x.x(1:6),2,3);0 0 1];
    Rm_est  = [ est_x.x(7:8)';0 1];
    Ai_est  = A_est;
    if par.test_symmetry
        disp('--- start symmetric estimation h->g ---')
        Ai_a = inv(A_a);
        Ri_a = [1/R_a(1),-R_a(2)/R_a(1)]
       
        % --- estimate transformation (LSM_62_sym_main) --------------------

        [est_xi,est_sigma_0i,NN,Nf,Redi,N_iter] = LSM_62_sym_warp_main...
            (h,g,vh,vg,Ai_a,Ri_a,sigma_smooth,max_iter,Nf_MIN,plot_type);

        % --- estimate transformation (LSM_62_sym_main) --------------------
        
        Ai_est  = [reshape(est_xi.x(1:6),2,3);0 0 1]
        Ami_est = [est_xi.x(7:8)';0 1]
    end
   


%% === analyse result ===================================================

image_pair_analyse(...
    A_a,  ...
    R_a, ...
    Ai_est, ...
    Red, ...
    est_sigma_0, ...
    est_x, ...
    par.plot_type,par.test_symmetry)
end
disp(' --------------------------------------------------------------------- ')
disp(' ---- symmetric LSM with 6 geometric and 2 radiometric parameters ---- ')
disp(' ----                            end                              ---- ')
disp(' --------------------------------------------------------------------- ')

return