%% Sym-LSM small demo
%
% The demo routine demo_LSM_small.m shows the most simple
% form of using of the main routine, here LSM_62_sym_warp_main.m.
% The required input data are loaded from file. The routine assumes the
% approximate values for the geometric transformation is given.
% Furthermore, the noise variance functions vg and vh are assumed to be
% provided, e.g. determined from a representative image using the routine
% noise_standard_deviation_estimation.m. The input images, the noise 
% standard deviations and the change of the estimated image windows are
% shown in figures.
%
% wf 7/2020


close all
clearvars
%clc

addpath(genpath('src/')) 

disp(' --------------------------------------------------------------------- ')
disp(' ---- Symmetric LSM with 6 geometric and 2 radiometric parameters ---- ')
disp(' ----------------- two corresponding windows ------------------------- ')
disp(' --- with given approximate values and noise characteristics --------- ')
disp(' --------------------------------------------------------------------- ')
%% set parameters
plot_type       = 1;        % degree of output
max_iter        = 7;        % maximum number of iterations
sigma_smooth    = 0;        % smoothing of estimated function f
Nf_MIN          = 4;        % minimum size of overlap

%% provide input data
% --- load data ---------------------------------------------------------
load('example_data/Sym_LSM_small_demo');
% g,h       two square images
% vg,vh     two 256x1 vectors of noise variances (LUT)
% A_a       3x3 matrix of approx. geometric transformation
% R_a       1x2 vector of approx. parameters of radiometric transformation

% --- show square images g and h ----------------------------------------
g=double(g);
h=double(h);
figure('name','given image patches')
hold on
subplot(1,2,1)
imshow(g/255);
title('left image')
subplot(1,2,2)
imshow(h/255);
title('right image')

% --- give geometric affinity A_(3x3) : z = A y -------------------------
disp( 'Approximate geometric transformation affinity  zh = Ah yh: ')
disp(A_a);
% --- give radiometric affinity R_(1x2): h = R1*y + R2 ------------------
disp(['Approximate intensity transformation h = R1*y + R2 [gr]  : [',...
    num2str(R_a(1)),',',num2str(R_a(2)*255),']'])

% ---  maximum number of iterations N_iter ------------------------------
disp(['Maximum number of iterations                             : ', num2str(max_iter)])

% ---  minimum size of overlap  ------------------------------
disp(['Minimum size of overlap                                  : ', num2str(Nf_MIN),'x', num2str(Nf_MIN)])

% ---  smoothing kernel sigma_smooth ------------------------------------
disp(['Smoothing kernel [pixels]                                : 0'])

% --- noise standard deviations vg and vh (256x1) -----------------------
figure('name','noise standard deviations');
    hold on
    plot(sqrt(vg),'-b','LineWidth',2);
    plot(sqrt(vh),'-r','LineWidth',2);
    title('Noise standard deviations: left (blue), right(red)')
    xlim([0,255])
    ylim([0,1.1*max([sqrt(vg);sqrt(vh)])])
    
%% === main routine Sym-LSM =============================================

disp('=== Iteration sequence =======================================')

[est_x,est_sigma_0,NN,Nf,Red,N_iter] = LSM_62_sym_warp_main...
    (g,h,vg,vh,A_a,R_a,sigma_smooth,max_iter,Nf_MIN,1);

%% === show results =====================================================
A_est   = [reshape(est_x.x(1:6),2,3);0 0 1];
    Rm_est  = [ est_x.x(7:8)';0 1];
    Ai_est  = A_est;
    
image_pair_analyse(...
    A_a,  ...
    R_a, ...
    Ai_est, ...
    Red, ...
    est_sigma_0, ...
    est_x, ...
    1,0);

disp(' --------------------------------- ')
disp(' ----  end demo symmetric LSM ---- ')
disp(' --------------------------------- ')


