function [fe,fes,fgi,fhi] = LSM_62_sym_estimate_f(g,h,vg,vh,Nf,xa,sigma,pt)
% estimate function f from g and h using xa and smooth.
%
% g,h       two images
% vg, vh    variance function
% Nf        half size of reference image
% xa        current geometric and radiometic transformation 
% sigma     stdv for smoothing
%
% fes       estimated and smoothed image
%
% wf 2018/11

% inverse geoemtric transformation
B  = [xa(1) xa(3) xa(5);xa(2) xa(4) xa(6);0 0 1];
R  = [xa(7);xa(8)];
Bi = inv(B);

% sizes
Ng = (size(g,1)-1)/2;

Nh = (size(h,1)-1)/2;

fe  = zeros(2*Nf+1);
fes = zeros(2*Nf+1);
fgi = zeros(2*Nf+1);
fhi = zeros(2*Nf+1);

for i=-Nf:Nf
    for j=-Nf:Nf
        % image g: dermine g-values of grid in f
        xgij = Bi * [i;j;1];
        xg = xgij(1) + Ng+1;
        yg = xgij(2) + Ng+1;
        if xg > 2*Ng || yg > 2*Ng || xg < 2  || yg < 2
            keyboard
        end
        %fg = (1+R(1))*LSM_f_spline(xg,yg,g)/255+R(2);
        fg =R(1)*LSM_f_cubic_interpolation(xg,yg,g)/255+R(2);
        wg = 1/vg(round(fg*255)+1)/R(1)^2;
        fgi(i+Nf+1,j+Nf+1) = fg;
        
        % image h: dermine h-values of grid in f
        xhij = B * [i;j;1];
        xh = xhij(1) + Nh+1;
        yh = xhij(2) + Nh+1;
        if xh > 2*Nh || yh > 2*Nh || xh < 2  || yh < 2
            keyboard
        end
        %fh= (LSM_f_spline(xh,yh,h)/255-R(2))/(1+R(1));
        fh= (LSM_f_cubic_interpolation(xh,yh,h)/255-R(2))/R(1);
        wh = 1/vh(round(fh*255)+1)*R(1)^2;
        fhi(i+Nf+1,j+Nf+1) = fh;
        
        % take weighted average:
        fe(i+Nf+1,j+Nf+1) = (wg*fg+wh*fh)/(wg+wh);
    end
end
if sigma > 0
    % smooth: to be used for derivatives.
    fes = gaussFFT(fe,sigma,'G');
else
    fes = fe;
end

if pt > 1
    figure('Name','Histogram of residuals of restaured images')
    subplot(1,2,1)
    hist(fgi(:)-fe(:),2*Nf+1);
    title(['mean(g-f) = ',num2str(mean(fgi(:)-fe(:)))])
    subplot(1,2,2)
    hist(fhi(:)-fe(:),2*Nf+1);
    title(['mean(h-f) = ',num2str(mean(fhi(:)-fe(:)))])
    Cov_fg=cov(fgi(:),fhi(:));
    
    %R1_est=sqrt(tan(0.5*atan2(2*Cov_fg(1,2),Cov_fg(2,2)-Cov_fg(1,1))))-1
end
end

