function I_true = LSM_62_sym_generate_image(par,plot_type)
%
%% Generate true image for demo simulated
% assumption: I_true \in  [0,255]
%
% call:
% I_true = LSM_62_sym_generate_image(par,plot_type)
%
% has a border of BOUND=3 on all sides compared to input,
% for allowing cubic interpolation and shift in [0,1]
%
% plot_type          in [0,1,2] for controlling output
%

%% prepare true values
a7_true = par.S_true(1);
a8_true = par.S_true(2);

Si_true =  1/(par.S_true(1))*[1,-par.S_true(2)];
a7i_true = Si_true(1);
a8i_true = Si_true(2);


%% determine image size
% forward
% square f
Nf=par.Nfr+par.BOUND;
bbf    = square_corners(Nf);
bbfr   = square_corners(par.Nfr);
% region f for g
bbfg  = par.Bi_true*bbf;
Ngr   = ceil(max(abs(bbfg(:))));
Ng    = Ngr + par.BOUND;
bbfgf = par.B_true*square_corners(Ng);
% region f for h
bbfh  = par.B_true*bbf;
Nhr   = ceil(max(abs(bbfh(:))));
Nh    = Nhr + par.BOUND;
bbfhf = par.Bi_true*square_corners(Nh);
% required size of image
Nif    = ceil(max(abs([bbfgf(:);bbfhf(:)])))+par.BOUND;

% backward
% square f
Nf=par.Nfr+par.BOUND;
bbf    = square_corners(Nf);
% region f for g
bbfg  = par.B_true*bbf;
Ngr   = ceil(max(abs(bbfg(:))));
Ng    = Ngr + par.BOUND;
bbfgf = par.Bi_true*square_corners(Ng);
% region f for h
bbfh  = par.Bi_true*bbf;
Nhr   = ceil(max(abs(bbfh(:))));
Nh    = Nhr + par.BOUND;
bbfhf = par.B_true*square_corners(Nh);
% required size of image
Nib    = ceil(max(abs([bbfgf(:);bbfhf(:)])))+par.BOUND;

Ni = max(Nif,Nib);

f_min_f=max(255*[a8_true,-a8_true])+5*par.sigma_max+10;  % in [0,255]
f_max_f=min([a7_true*255+a8_true*255,(255-a8_true*255)/a7_true])-5*par.sigma_max-10;
f_min_b=max(255*[a8i_true,-a8i_true])+5*par.sigma_max+10;  % in [0,255]
f_max_b=min([a7i_true*255+a8i_true*255,(255-a8i_true*255)/a7i_true])-5*par.sigma_max-10;
f_min=max(f_min_f,f_min_b);
f_max=min(f_max_f,f_max_b);

%% artificial image or read in image
if strcmp(par.img_filename(1:6),'square')
    
    I_true = LSM_generate_square(Ni,Nf,f_min,f_max,par.par);
    
    if plot_type > 0
        figure('name','true image');
        colormap('gray')
        imagesc(I_true);
        axis equal
    end
end
if strcmp(par.img_filename(1:6),'waves2')
    I_true = LSM_generate_waves2(Ni,f_min,f_max,par.par);
    
    if plot_type > 0
        
        figure('name','true image');
        colormap('gray')
        imagesc(I_true);
        axis equal
    end
end
if strcmp(par.img_filename(1:6),'MIT.pn')
    
    % read and generate true image
    I_true = LSM_generate_true_image(par.img_filename,par.row,par.col,Ni);
    I_true = (double(I_true)*(f_max-f_min)/255 + f_min);
    
end
if strcmp(par.img_filename(1:6),'random')
    
    [fa,~,~] = LSM_generate_random(Ni,f_min,f_max,par.par);
    I_true   = reshape(fa(:,1),2*Ni+1,2*Ni+1);
    
    if plot_type > 0
        
        figure('name','true image');
        colormap('gray')
        imagesc(I_true);
        axis equal
    end
end

if plot_type > 1
    plot_size = max([Ni,Nf,Ng,Nh])+2;
    
    
    figure('name','mean, left and right: boundaries');
    subplot(2,3,2)
    hold on
    plot_quadrangle(square_corners(Ni),'-r')
    plot_quadrangle(square_corners(Nf),'-k')
    plot_quadrangle(square_corners(par.Nfr),'--k')
    plot_quadrangle(bbfgf,'-b')
    plot_quadrangle(bbfhf,'-g')
    xlim([-plot_size,plot_size])
    ylim([-plot_size,plot_size])
    axis equal
    
    subplot(2,3,4)
    hold on
    plot_quadrangle(square_corners(Ng),'-b')
    plot_quadrangle(square_corners(Ngr),'--b')
    plot_quadrangle(par.Bi_true*bbfr,'--k')
    plot_quadrangle(par.Bi_true*bbf,'-k')
    xlim([-plot_size,plot_size])
    ylim([-plot_size,plot_size])
    
    axis equal
    
    subplot(2,3,6)
    hold on
    plot_quadrangle(square_corners(Nh),'-g')
    plot_quadrangle(square_corners(Nhr),'--g')
    plot_quadrangle(par.B_true*bbfr,'--k')
    plot_quadrangle(par.B_true*bbf,'-k')
    xlim([-plot_size,plot_size])
    ylim([-plot_size,plot_size])
    
    axis equal
    
end

end

