%% LSM_62_sym_generate_noisy_observing_images
%
% add noise to true images
%
% call:
% [g,h] = LSM_62_sym_generate_noisy_observing_images...
%                    (g_true,h_true,vg,vh,plot_type)
%
% g_true,h_true     true images (square), in [0:255]
% plot_type         in [0,1,2] controlling output
%
% g,h               % noisy images, in [0:255]
% std_i_g, std_i_h      % standard deviations of cubic interpolation error
%
% wf 12/2019

function [g,h,std_i_g,std_i_h,par] = LSM_62_sym_generate_noisy_observing_images...
    (g_true,h_true,par)

%% generate first image
Mg = size(g_true,1);
gv = min(255,max(0,round(g_true(:) +...
    randn(Mg^2,1).*sqrt(par.vg(round(g_true(:))+1)))));
g = reshape(gv,Mg,Mg);

%% generate second image
Mh = size(h_true,1);
hv = min(255,max(0,round(h_true(:) +...
    randn(Mh^2,1).*sqrt(par.vh(round(h_true(:))+1)))));
h = reshape(hv,Mh,Mh);

%% determine standard deviation of double bicubic interpolation error
diff_g   = conv2(g,par.Diff_filter,'valid');
diff_h   = conv2(h,par.Diff_filter,'valid');
std_i_g  = std(diff_g(:));
std_i_h  = std(diff_h(:));

%% plots
if par.plot_type > 1
    figure('Name','generated true images')
    
    subplot(3,3,7);imshow(double(g)/255);title('g');axis equal
    %         xlim([-plot_size,plot_size])
    %         ylim([-plot_size,plot_size])
    subplot(3,3,9);imshow(double(h)/255);title('h');axis equal
    %         xlim([-plot_size,plot_size])
    %         ylim([-plot_size,plot_size])
    colormap(gray)
    
    std_g_and_h = std([g(:);h(:)]-[g_true(:);h_true(:)])
end
end

