%% LSM_generate_true b/w image generates true image from RGB-image on file
%
% I_true=LSM_generate_true_image(img_filename,row,col,Ni)
%
% img_filename  file name (without path)
% row, col      row and column f window
% Ni            half size of window
%
% I_true        true image used for generating observed images
%
% wf 09/2012
%

function [I_true,N1,M1]=LSM_generate_true_image(img_filename,row,col,Ni)

% input image
I_ori = imread(['example_data/Images/',img_filename]);
[N1,M1,channels] = size(I_ori);
% guarantee I_true is square with odd number of pixels
N = 2*floor(min(N1,M1)/2)-1;

if  max([row,col]) < N-Ni &&  min([row,col]) > Ni
    
    I_orig=I_ori(1:N,1:N);
    % if color then make graylevel
    if channels == 3
        Ig = double(rgb2gray(I_orig));
    else
        Ig = I_orig;
    end
    I_ori(row-Ni:row+Ni,col-Ni)=255*ones(1,2*Ni+1);
    I_ori(row-Ni:row+Ni,col+Ni)=255*ones(1,2*Ni+1);
    I_ori(row-Ni,col-Ni:col+Ni)=255*ones(2*Ni+1,1);
    I_ori(row+Ni,col-Ni:col+Ni)=255*ones(2*Ni+1,1);
    figure
    imshow(I_ori);
    
    % smooth
    
    Box = [0 0 1 4 6 4 1 0 0]'/16;
    ad = (length(Box)-1)/2;
    I_g_r    = conv2(single(Ig),Box);
    I_g_rc   = conv2(I_g_r,Box');
    
    % select window
    I_true = uint8(round(I_g_rc(row-Ni+ad:row+Ni+ad,col-Ni+ad:col+Ni+ad)));
    
else
    display(['wrong window selection']);
    stop
end



return