function [g,h,x_approx,par] = image_pair_approximate_values_weights(Nig,Nih,Image_l,Image_r,X,par)
%% approximate values for geometric transformation, variance functions
%
% wf 7/2020

%% === estimate noise variances ======================================
if par.readX == 0   % measure image correspondencies
    
    % --- estimate noise variance g ---------------------------------------
    % half size of area for dermining noise variance
    DD    = max([100,Nig]);     
    [M,N] = size(Image_l);
    % determine bounding box within Image_l
    x_min = max([1,X(1,1)-DD]);
    y_min = max([1,X(1,2)-DD]);
    x_max = min([M,X(1,1)+DD]);
    y_max = min([N,X(1,2)+DD]);
    % estimate noise standard deviations
    [s_g,m_g,~] = noise_standard_deviation_estimation(Image_l(x_min:x_max,y_min:y_max,:));
    
    % take mean of channels
    stg          = mean(s_g,1)'*256;
    
    display(['avg. noise std [gr] left                         : ', ...
        num2str(mean(stg))])
    
    par.vg        = stg.^2;
    
    % --- estimate noise variance h ---------------------------------------
    % half size of area for dermining noise variance
    DD    = max([100,Nih]);
    [M,N] = size(Image_r);
    % determine bounding box within Image_r
    x_min = max([1,X(2,1)-DD]);
    y_min = max([1,X(2,2)-DD]);
    x_max = min([M,X(2,1)+DD]);
    y_max = min([N,X(2,2)+DD]);
    % estimate noise standard deviations
    [s_h,m_h,~] = noise_standard_deviation_estimation(Image_r(x_min:x_max,y_min:y_max,:));
    % take mean of channels
    sth          = mean(s_h,1)'*255;
    display(['avg. noise std [gr] right                        : ', ...
        num2str(mean(sth))])
    
    par.vh        = sth.^2;
    
    % show average noise standard deviation over channels
    figure('name','noise standard deviations');
    hold on
    plot(mean(s_g,1)*255,'-b','LineWidth',2);
    plot(mean(s_h,1)*255,'-r','LineWidth',2);
    title('Noise standard deviations: left (blue), right(red)')
    xlim([min([m_g(:);m_h(:)]),max([m_g(:);m_h(:)])]*255)
    ylim([0,1.1*max([mean(s_g,1)'*255;mean(s_h,1)'*255])])
    
    % save
    save(par.coordinate_name,'X','par');
    
else
    % load
    load(par.coordinate_name,'X','par');
    
end

%% === true affinity referring to centre of window =====================
D = [X(2,3)/X(1,3)*eye(2),[0;0];0 0 1];     % relative scaling
alpha = X(2,4)-X(1,4);                      % rotation
R = [cos(alpha) -sin(alpha) 0;sin(alpha) cos(alpha) 0;0 0 1];
par.A_a   = D*R;                            % similarity
% half transformation A=B^2
par.B_a   = sqrtm(par.A_a);
par.Bi_a  = inv(par.B_a);

% --- approximate values ----------------------------------------------
par.Ai_a = inv(par.A_a);
% Approximate geometric affinity z = A y
disp([ 'Scale difference                                 : ',num2str(X(2,3)/X(1,3))])
disp([ 'Rotation difference                              : ',num2str(alpha*180/pi), ''])
disp( 'Geometric affinity       z = A y                 : ')
disp(par.A_a);

x_approx = [reshape(par.A_a(1:2,:),6,1);par.R_a'];

%% select windows ======================================================

g = round(mean(Image_l(X(1,1)-Nig:X(1,1)+Nig,X(1,2)-Nig:X(1,2)+Nig,:),3));
h = round(mean(Image_r(X(2,1)-Nih:X(2,1)+Nih,X(2,2)-Nih:X(2,2)+Nih,:),3));

if par.plot_type > 0
    figure('name','left and right image window')
    subplot(1,2,1)
    imshow(g/255)
    title('left')
    subplot(1,2,2)
    imshow(h/255)
    title('right')
end


end

