function par = image_pair_noise_variances(Nig,Nih,Image_l,Image_r,X,par)
%% estimate noise varainces of images
%
% Nig, Nih          radius of windows
% Image_l,Image_r   left and right image
% X                 2x4 matrix of correspoinindg points (x,y,s,d)
% par               parameter-struct
%
% par.vg, par.vh    256x1 vectors (LUT) for noise variance 
%                   Var(g) = LUT(g+1)
% par.A_true        true geometric affinity
% par.B_true        true half geometric affinity
% par.Bi_true       true half inverse geometric affinity
% par.A_a           approximate geometric affinity
% par.B_a           approximate half geometric affinity
%
% wf 7/2020


%% === estimate noise variances g ======================================
% --- half size of area for dermining noise variance -------------------
DD    = max([100,Nig]);
[M,N] = size(Image_l);
x_min = max([1,X(1,1)-DD]);
y_min = max([1,X(1,2)-DD]);
x_max = min([M,X(1,1)+DD]);
y_max = min([N,X(1,2)+DD]);
[s_g,m_g,~] = noise_standard_deviation_estimation(Image_l(x_min:x_max,y_min:y_max,:));

stg          = mean(s_g)'*256;

display(['avg. noise std [gr] left                         : ', ...
    num2str(mean(stg))])
par.vg        = stg.^2;


%% === estimate noise variances h =======================================

% half size of area for dermining noise variance
DD    = max([100,Nih]);
[M,N] = size(Image_r);
x_min = max([1,X(2,1)-DD]);
y_min = max([1,X(2,2)-DD]);
x_max = min([M,X(2,1)+DD]);
y_max = min([N,X(2,2)+DD]);

[s_h,m_h,~] = noise_standard_deviation_estimation(Image_r(x_min:x_max,y_min:y_max,:));

sth          = mean(s_h)'*255;
display(['avg. noise std [gr] right                        : ', ...
    num2str(mean(sth))])

par.vh        = sth.^2;

%% === true affinity referring to centre of window =====================
D = [X(2,3)/X(1,3)*eye(2),[0;0];0 0 1];
alpha = X(2,4)-X(1,4);
R = [cos(alpha) -sin(alpha) 0;sin(alpha) cos(alpha) 0;0 0 1];
par.A_true   = D*R;
% half transformation A=B^2
par.B_true   = sqrtm(par.A_true);
par.Bi_true  = inv(par.B_true);

% --- approximate values ----------------------------------------------
par.A_a  = par.A_true;
par.Ai_a = inv(par.A_a);
% Approximate geometric affinity z = B y
    display([ 'Scale difference                                 : ',num2str(X(2,3)/X(1,3))])
    display([ 'Rotation difference                              : ',num2str(alpha*180/pi), ''])
    display( 'Geometric affinity       z = B y                 : ')
    display(A_a);


%% select windows ======================================================

Nih = round(factor_s*X(2,3));

        
g = round(mean(Image_l(X(1,1)-Nig:X(1,1)+Nig,X(1,2)-Nig:X(1,2)+Nig,:),3));
h = round(mean(Image_r(X(2,1)-Nih:X(2,1)+Nih,X(2,2)-Nih:X(2,2)+Nih,:),3));

if plot_type > 1
    figure(9)
    subplot(max_iter+1,4,1)
    imshow(g/255)
    title('left')
    subplot(max_iter+1,4,2)
    imshow(h/255)
    title('right')
end

%% 

figure('name','noise standard deviations');
hold on
plot(mean(s_g)*255,'-b','LineWidth',2);
plot(mean(s_h)*255,'-r','LineWidth',2);
title('Noise standard deviations: left (blue), right(red)')
xlim([min([m_g(:);m_h(:)]),max([m_g(:);m_h(:)])]*255)
ylim([0,1.1*max([mean(s_g)'*255;mean(s_h)'*255])])

end

