function par = image_pair_set_parameters(par);
%% sets all control parameters
%
% par.BOUND             boundary, constant
% par.init_rand         initial random number
% par.readX             0/1: read coordinates
% par.type_data         type of image generation
% par.test_symmetry     0/1: test on symmetry
% par.im_path           path for images
% par.Image_name_l      name of left image
% par.Image_name_r      name of right image
% par.pt_path           path for image coordiantes
% par.plot_type         in [0,1,2]: control of output
% par.plot_params.f1    background of keypoint
% par.plot_params.f2    foreground of keypoint
% par.R_a               1x2, approximate radiometric transformation
% par.factor_s          factor for window size Nfr=f*sigma_Lowe
% par.sigma_smooth      smoothing parameter for f
% par.max_iter          maximum number of iterations
% par.Nf_MIN            minimum size of overlap (radius of f)
% par.S                 significance level
% par.Diff_filter       kernel for bi-cubic interpolation error
%
% wf 7/2020

par.BOUND     = 3;

% --- initial random number --------------------------------------------
% --- initiate random numbers ------------------------------------------
par.init_rand    = 4;
par.init_rand=init_rand_seed(par.init_rand);

% --- read coordinates from file? ------- -------------------------------
par.readX = 1;
%par.readX = 0;

% --- Test symmetry ----------------------------------------------------
par.test_symmetry=0;

% --- type data --------------------------------------------------------
if par.type_data == 0
    % par.type_data = 1;  % Desert
    par.type_data = 2;  % Stockholm
    % par.type_data = 3;  % % Peking
    % par.type_data = 4;   % % Prag
end

switch par.type_data
    case 1
        % Desert
        par.im_path = 'example_data/Images/';
        par.Image_name_l = 'IMG_6703-a.JPG';
        par.Image_name_r = 'IMG_6705-a.JPG';
    case 2
        % Stockholm
        par.im_path = 'example_data/Images';
        par.Image_name_l = 'IMG_1557-a.JPG';
        par.Image_name_r = 'IMG_1560-a.JPG';
    case 3
        % Peking
        par.im_path = 'example_data/Images';
        par.Image_name_l = 'IMG_1134-a.JPG';
        par.Image_name_r = 'IMG_1137-a.JPG';
    case 4
        % Prag
        par.im_path = 'example_data/Images';
        par.Image_name_l = 'IMG_8893-a.JPG';
        par.Image_name_r = 'IMG_8892-a.JPG';
        
        
end
par.pt_path = 'example_data/ImageCoordinates/';

% --- output level -----------------------------------------------------
par.plot_type = 1;

% --- linewidths for plotting rectangles -------------------------------
par.plot_params.f1 = 9;    % black (background)
par.plot_params.f2 = 4;    % yellow (foreground)

% --- Approximate radiometric affinity h = b7*y + b8 -------------------
par.R_a             = [1,0];

% --- size of window/scale ---------------------------------------------
par.factor_s = 4;

% -- minimum size of overlap (radius of f) -----------------------------
par.Nf_MIN = 4;

% ---  smoothing kernel ------------------------------------------------
par.sigma_smooth        = 0;

% --- maximum number of iterations ------------------------------------
par.max_iter  = 7;

% --- significance level ----------------------------------------------
par.S = 0.999;


% kernel for estimating interpolation error
par.Diff_filter = [ ...
    [  1/65536,   -9/32768,   63/65536,   41/16384,   63/65536,   -9/32768,  1/65536]; ...
    [ -9/32768,   81/16384, -567/32768,  -369/8192, -567/32768,   81/16384, -9/32768]; ...
    [ 63/65536, -567/32768, 3969/65536, 2583/16384, 3969/65536, -567/32768, 63/65536]; ...
    [ 41/16384,  -369/8192, 2583/16384, -2415/4096, 2583/16384,  -369/8192, 41/16384]; ...
    [ 63/65536, -567/32768, 3969/65536, 2583/16384, 3969/65536, -567/32768, 63/65536]; ...
    [ -9/32768,   81/16384, -567/32768,  -369/8192, -567/32768,   81/16384, -9/32768]; ...
    [  1/65536,   -9/32768,   63/65536,   41/16384,   63/65536,   -9/32768,  1/65536]];

end

