function sym_lsm_analysis(...
    r_sample,...
    est_sigma_0,...
    est_x,...
    est_xi,...
    est_xs, sigma_0s, N_iters,...
    Red,...
    lsm_time,...
    par)

%% analysis of Sym-LSM
%
% r_sample          number of successful samples
% sigma_0_est       sqrt of estimated variance factor
% est_x             estimated parameters (est_x.x and est_x.C)
% est_xi            estimated parameters of symmetric solution, ...
% est_xs, sigma_0s, N_iters
%                   list of estimated parameters, sigma_0s and iterations
% Red               redundancy
% lsm_time          total CPU time for all samples.
%
% wf 7/2020



% successful samples
Nr_samples = r_sample;

if par.N_samples-Nr_samples > 0
    if par.N_samples-Nr_samples ==1
        disp(['Warning: ',num2str(par.N_samples-Nr_samples),...
            ' sample reached maximum number of iterations ',...
            num2str(par.max_iter)])
    else
        disp(['Warning: ',num2str(par.N_samples-Nr_samples),...
            ' samples reached maximum number of iterations ',...
            num2str(par.max_iter)])
    end
end

if Nr_samples > 9
    
    
    if par.plot_type > 1
        sigma_0_est=est_sigma_0
    end
    
    if par.plot_type > 1
        est_xs
        sigma_rho=Covariance_2_sigma_rho(Tg_est.C)
    else
        check_estimation_result(Red, par.x_true, est_x.C,...
            sigma_0s(1:Nr_samples).^2, est_xs(1:Nr_samples,:), par.S, ' LSM-62-sym all');
        
        
        
        check_estimation_result(Red, par.x_true(1:6), est_x.C(1:6,1:6),...
            sigma_0s(1:Nr_samples).^2, est_xs(1:Nr_samples,1:6), par.S, ' LSM-62-sym affinity');
        
        figure
        hist(N_iters,[2:2:2*(par.max_iter+1)]/2)
        title(['Histogram of number of iterations,  LSM-62-sym'])
    end
    
    if par.plot_type > 0
        disp(' ')
        disp('Standard deviations and differences to ground truth')
        disp('---------------------------------------------------')
        disp(['     a1        a2        a3        a4        a5',...
            '        a6        a7        a8'])
        
        sigmas_theor      = sqrt(diag(est_x.C)')
        sigmas_empir      = sqrt(diag(cov(est_xs))')
        ratio_sigma_empir_sigma_theor = sigmas_empir./sigmas_theor
        Mean_difference_to_ground_truth       = mean(est_xs) - par.x_true'
        Std_difference_to_ground_truth        = std(est_xs)
        Max_difference_to_ground_truth        = max(abs(est_xs - ones(par.N_samples,1)*par.x_true'))
    end
    
    disp(' ')
    disp(['sigma affinity        [%] : ',...
        num2str(100*mean(sqrt(diag(est_x.C(1:4,1:4))')))])
    disp(['sigma shift       [pixel] : ',...
        num2str(mean(sqrt(diag(est_x.C(5:6,5:6))')))])
    disp(['sigma intensity      [gr] : ',...
        num2str(mean(sqrt(diag(est_x.C(7:8,7:8))'))*255)])
    disp(' ')
    disp(['time per iteration    [ms]: ', num2str(1000*lsm_time/sum(N_iters))])
    disp(['time per observation  [ms]: ', num2str(1000*lsm_time/sum(N_iters)/(Red+8))])
    %     time_per_LSM = lsm_time/N_samples
    %     time_per_observation = time_per_LSM/(Red+8)
    
else
    
    A_est   = [reshape(est_x.x(1:6),2,3)]
    Rm_est  = [est_x.x(7:8)']
    
    if par.plot_type > 0
        
        A_estimated   = [reshape(est_x.x(1:6),2,3);0 0 1];
        if par.test_symmetry
            Ainv_estimated  = [reshape(est_xi.x(1:6),2,3);0 0 1]
        end
        R_estimated  = [est_x.x(7:8)'; 0 1];
        if par.test_symmetry
            Rinv_estimated = [est_xi.x(7:8)'; 0 1]
        end
        A_differences_to_ground_truth = A_estimated(1:2,:) - par.A_a(1:2,:)
        R_differences_to_ground_truth = R_estimated(1,:) -par.R_a
        if par.test_symmetry
            cA =A_estimated*Ainv_estimated-eye(3);
            cR =R_estimated*Rinv_estimated-eye(2);
            check_symmetry_AAi_I =cA(1:2,:)
            check_symmetry_RRi_I =cR(1,:)
        end
        
        
        A_standard_deviations        = reshape(sqrt(diag(est_x.C(1:6,1:6))'),2,3)
        
        R_standard_deviations        = reshape(sqrt(diag(est_x.C(7:8,7:8))'),1,2)
    end
    
    
end

if par.plot_type > 1
    test_bias_z =(est_x.x-par.x_true)'./sqrt(diag(est_x.C))';
end

end

