% LSM_jacobian_g1_g2 for least squares matching
%
% Xm  =  LSM_62_sym_jacobian_g_h(fe,fes,g,h,yi,zi,A,R,pt)
%
% fe         = estimated image
% fes        = smoothed image
% g,h        = observations of image
% zyi,zi     = list of observed pixels
% A          = actual estimates for geometric transformation
% R          = actual estimates for radiometric transformation
% pt         boolean for plot/print

function Xm  = LSM_62_sym_jacobian_g_h(fe,fes,g,h,yi,zi,A,R,pt)

% number of observations
Kg   = size(1,yi);
Kh   = size(1,zi);

NN=Kg+Kh;
NU=6;

Xm=zeros(NN,NU);

fak  = 1+R(1);
faki = 1/fak;

%% Jacobians: first image
for k = 1:Kg
    i=yi(1,i);                      % pixel coordinates in g
    j=yi(2,i);
    xh = A*[i;j;1];                 % real coordinates in f (centred)
    x=xh(1);
    y=xh(2);
    fij  = LSM_f_spline(x,y,fe);    % estimated signal 
    fxij = LSM_fx_spline(x,y,fes);  % gradient at smoothed signal
    fyij = LSM_fxy_spline(x,y,fes);
    % Jacobian
    Xm(k,:) = [fxij*x fyij*x fxij*y fyij*y fxij fyij -fij*faki -fak]*faki;
end



% second image: gradients averaged
for k=Kg+1:Kg+Kh;
    i=zi(1,i);                      % pixel coordinates in h
    j=zi(2,i);
    xh = Ai*[i;j;1];                % real coordinates in f (centred)
    x=xh(1)+Nh;
    y=xh(2)+Nh;
    fij  = LSM_f_spline(x,y,fe);    % estimated signal 
    fxij = LSM_fx_spline(x,y,fes);  % gradient at smoothed signal
    fyij = LSM_fy_spline(x,y,fes);
    pij = Ai'*[fxij;fyij];          % gradient in f
    pxij=pij(1);        
    pyij=pij(2);
    Xm(k,:) = -[pxij*x pyij*x pxij*y pyij*y pxij pyij -pij*faki -paki]*fak;
end

 
return