% LSM_generate_square generates square image with suqare
%
% [I,u,F] = LSM_generate_square(Nf,par)
%
% Nf    = size of square
% f_min = minimum intensity
% f_ma  = maximum intensity
% par   = [f,s] frequency: size is Nf/f
%               std of edges s
%
% I     = image with Gaussian process
% u,F   = frequencies and amplitudes

function [fa,u,F]=LSM_generate_random(Nf,f_min,f_max,par)

bandwidth = par(1);
mean_a    = par(2);
sigma_a   = par(3);
K         = par(4);
dx        = par(5);

range_f   =    (-Nf:Nf)*dx;
[X,Y]     = meshgrid(range_f,range_f);
xv        = X(:);
yv        = Y(:);

% generate F for ideal signal f
[u,F] = generate_F_Gauss_2D(mean_a,sigma_a,bandwidth,K);

% generate ideal signal at N points (1:N) including gradient
fa          = signal_from_F_2D(u,F,xv,yv,[[0,0];[0,1];[1,1]]);
fa_max = max(fa(:,1));
fa_min = min(fa(:,1));
fa(:,1) = floor((f_max-f_min) * (fa(:,1)-fa_min)/(fa_max-fa_min) + f_min);
fa(:,2) = fa(:,2)*(f_max-f_min)/(fa_max-fa_min);
return