% LSM_generate_waves2 generates square image with 2 waves
%
% I = LSM_generate_waves2(N0,b)
%
% N0    = size of image
% f_min = minimum intesity
% f_max = maximum intesity
% par   = [f,sharp], f = frequency (sin(f*...))
%
% I     = image with waves/checkerboard

function I=LSM_generate_waves2(N0,f_min,f_max,par)

% frequency
f = par(1);
% size of image
N=2*N0+1; 
% generate wave in [-1,+1]
for i=1:N
    for j=1:N
        I(i,j)=sin(f*pi*i/N)*sin(f*pi*j/N);
    end
end
if par(2) > 0
    % generate sharp edges
    I = sign(I);
    % smooth a bit
    % kernel = [1,4,6,4,1]'*[1,4,6,4,1]/256;
    s = par(2);
    N = 2*ceil(2*s)+1;
    alpha=(N-1)/2/s;
    ker = gausswin(N,alpha);
    ker = ker/sum(ker);
    kernel = ker*ker';
    I = conv2(I,kernel,'same');
end
% enforce intensity range
I = floor((f_max-f_min) * (1+I)/2 + f_min);
return