%% determine signal f(i) = sum_k F(k,l)*exp(2*pi*(i*k+j*l)/N)
%
% u       Mx2 matrix of frequencies
% F       Mx1 matrixr of complex amplitudes
% xv,yv   2 Nx1 vectors of x-values = y-values
% der     Dx2 matrixr of derivatives, containing:
%         f:  [0,0] = 0, fx: [1,0] = 1, fy: [0,1] = 3, 
%         fxx:[2,0] = 2, fxy:[1,1] = 4, fyy:[0,2] = 6
%
% S       NxD vector of signal/derivatives 
%
% wf 3/2020

function S = signal_from_F_2D(u,F,xv,yv,der)


if nargin == 4  % signal as default output
    der=[0,0];
end

K     = size(u,1);
N     = length(xv);    % number of data points in 1D
D     = size(der,1);        % number of derivatives 
ind_x = 1:N;                % index
S     = [];
for d=1:D
    k=der(d,1)+3*der(d,2);
    switch k
        case 0
            f(ind_x)   = ...
                sum(...
                repmat(F,1,N)      ...
                .*exp( 1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')) +...
                repmat(conj(F),1,N)...
                .*exp(-1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')))/2;
        case 1
            f(ind_x) = ...
                sum(...
                repmat(F      .*( 1i*2*pi*u(:,1)),1,N)...
                .*exp( 1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')) +...
                repmat(conj(F).*(-1i*2*pi*u(:,1)),1,N)...
                .*exp(-1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')))/2;
        case 3
            f(ind_x) = ...
                sum(...
                repmat(F      .*( 1i*2*pi*u(:,2)),1,N)... 
                .*exp( 1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')) +...
                repmat(conj(F).*(-1i*2*pi*u(:,2)),1,N)... 
                .*exp(-1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')))/2;
        case 2
            f(ind_x) = ...
                sum(...
                repmat(F      .*( 1i*2*pi*u(:,1)).*( 1i*2*pi*u(:,1)),1,N)...
                .*exp( 1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')) +...
                repmat(conj(F).*(-1i*2*pi*u(:,1)).*(-1i*2*pi*u(:,1)),1,N)...
                .*exp(-1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')))/2;
            
        case 4
            f(ind_x) = ...
                sum(...
                repmat(F      .*( 1i*2*pi*u(:,1)).*( 1i*2*pi*u(:,2)),1,N)...
                .*exp( 1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')) +...
                repmat(conj(F).*(-1i*2*pi*u(:,1)).*(-1i*2*pi*u(:,2)),1,N)...
                .*exp(-1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')))/2;
        case 6
            f(ind_x) = ...
                sum(...
                repmat(F      .*( 1i*2*pi*u(:,2)).*( 1i*2*pi*u(:,2)),1,N)...
                .*exp( 1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')) +...
                repmat(conj(F).*(-1i*2*pi*u(:,2)).*(-1i*2*pi*u(:,2)),1,N)...
                .*exp(-1i*2*pi*(u(:,1)*xv'+u(:,2)*yv')))/2;
    end
    S=[S,f(:)];   
end